/*H**********************************************************************
* FILENAME :        MEGA_BUILD.ino            DESIGN REF: V3
*
* DESCRIPTION :
*       This code controls the ARDUINO MEGA for the project 
*     
*
* NOTES :
*       Control code for the Arduino Mega
*       Make sure to check pins and wires
*
*       Copyright Adler Planetarium. 2019, 2020.  All rights reserved.
*
* AUTHOR :    Juan Landi     START DATE :    20 Jul 2020
*
* CHANGES :   Final Version (No Changes)
*
*
------------------------------------------------------------------------->H*/

// Libraries
#include <IRremote.h>                                        // IR receiver
#include <Adafruit_GFX.h>                                    // For OLED screen
#include <Adafruit_SSD1306.h>
                    
#include <SD.h>                                              // SD card Libraries
#include <SPI.h>
#include <Wire.h>

#define OLED_RESET -1                                        // Should be -1 if sharing with arduino

#define PDsensor A0
#define pingPin 8                                            // The two Ultrasonic sensor Pins
#define echoPin 9
#define irrecv_dpin 13                                       // IR Receiver Pin

#define led1 2                                               // LED pins
#define led2 3
#define led3 4
#define led4 5

IRrecv irrecv(irrecv_dpin);                                  // Initializes the IR Receiver Object
decode_results results;

Adafruit_SSD1306 display(128, 64, &Wire, OLED_RESET);        // Initializes the OLED screen

int OLED_state = 000;                                        // Three variables to keep track of OLED screen state
int UL_state = 001;
int pastO_state = 000;

int h = 0;                                                   // Breakdown of OLED_state varaible 
int t = 0;                                                   // H undreds digit, T ens digit, O nes Digit
int o = 0;

String remoteVal="0";                                        // Two variables to keep track of IR Receiver codes
int shortRemoteVal;

long duration, cm;                                           // Keeps track of Ultrasonic Sensor data

int lightVal;                                                // Keeps track of Photoresistor data     
                 
unsigned long startTime;                                     // Time keeping for Light-Freqeuncy Sensor and          
unsigned long currentTime;                                   // data recording with the SD card

unsigned long bootTime;                                      // Tracks first time activating SD Card after 
bool isBooted= false;                                        // everytime you want to record

unsigned long sensorDetect;                                  // Start time of detection of PIR Sensor / US sensor
unsigned long idleTime = 10000;                                       // Idle time after lights turn on in ms


int ledMaxBrightness = 255;                                   // The brightest the LEDs will ever get
int ledCurrBrightness = 0;                                   // Current brightness if the LEDs

int usMaxRange = 30;                                         // Ultrasonic Sensro max range (When to trigger it)
int usMinRange = 5;                                          // Ultrasonic Sensor min range (When to stop the lights)

int pdDayLight = 60;                                         // PhotoDiode Sensor Brightness level to detect daytime
int pdNightLight = 10;                                       // PhotoDiode Sensor Brightness level to detect nighttime

bool isRecording = false;
  

const unsigned char myBitmap [] PROGMEM = {                  // Boot Picture for the OLED
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xfc, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xfe, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xfe, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xfe, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xf8, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xc7, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0x1f, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x63, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xff, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xe0, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xff, 0xff, 0xf0, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0xff, 0xff, 0xf0, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xff, 0xf0, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3b, 0xff, 0xff, 0xf8, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x77, 0xff, 0xff, 0xf8, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe7, 0xff, 0xff, 0xfc, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xc7, 0xff, 0xff, 0xfc, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x8f, 0xff, 0xff, 0xfc, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x0f, 0xff, 0xff, 0xfe, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x0e, 0x1f, 0xff, 0x3f, 0xfe, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x1f, 0xff, 0x1f, 0xff, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x1f, 0xff, 0x1f, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x3f, 0xfe, 0x0f, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x3f, 0xfe, 0x0f, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x7f, 0xfc, 0x0f, 0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x7f, 0xfc, 0x07, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x7f, 0xfc, 0x07, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0xff, 0xf8, 0x07, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0xff, 0xf8, 0x03, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x61, 0xff, 0xf0, 0x0f, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x31, 0xff, 0xf0, 0x3f, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x39, 0xff, 0xe0, 0xf1, 0xff, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xff, 0xe7, 0xc0, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0xff, 0xfe, 0x00, 0xff, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xff, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};

void setup() {
  Serial.begin(115200);                                      // Begin Serial Comms
  Serial.println("Booting");

  irrecv.enableIRIn();                                       // Allow input from the IR Receiver

  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);                 // Begin OLED Screen 
  display.clearDisplay();                                    // Yours might use 0x3D instead of 0X3C
  display.drawBitmap(0, 0, myBitmap, 128, 64, WHITE);        // Draws the Logo screen on the OLED
  display.display();                                         // and displays it
  
  pinMode(PDsensor, INPUT);
  

  delay(2000);                                               // Waits 2 seconds
  
  startTime = millis();                                      // Sets start time as we enter the loop

}

void loop() {
  
  pinMode(pingPin, OUTPUT);                                  // Sends Ultrasonic Pulse from Ultrasonic Sensor
  digitalWrite(pingPin, LOW);
  delayMicroseconds(2);
  digitalWrite(pingPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(pingPin, LOW);
  pinMode(echoPin, INPUT);
  duration = pulseIn(echoPin, HIGH);                         // Reads duration it took to return and stores it
  cm = microsecondsToCentimeters(duration);                  // Does math to convert the time to distance in centimeters

  Serial.print(cm);                                          // Prints distance to Serial port
  Serial.println(" cm");

  lightVal = analogRead(PDsensor);                           // Reads from the Photodiode and stores it
  Serial.print(PDsensor);                                    // Prints value into the Serial Port
  Serial.println(" PD value");

  OLEDcontrol();                                             // Runs OLED Control function

  lightsControl();                                           // Runs the LED Lights Control function
}

long microsecondsToCentimeters(long microseconds) {          // Converts time to duration for the Ultrasonic sensor
   return microseconds / 29 / 2;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void lightsControl() {                                      // Controls the LED lights
  float distRange = (cm - usMinRange) * 100 / (usMaxRange - usMinRange); // Percentage range for the Ultrasonic sensor
  
  bool USstartedFirst = false;                              // Keeps track of which sensor got triggered first
                                                            
  if (!USstartedFirst) {                // Turns on the corresponding sensor variable
    if (cm < usMaxRange) {
      USstartedFirst = true;
      Serial.println("Started US sensor");
      sensorDetect = millis();
    }
  }
                                                            // Decides when to turn off the sensor tracking
  if ((cm > usMaxRange) && (millis() - sensorDetect > idleTime)) {
    USstartedFirst = false;
    Serial.println("Idle TIme Exceeded");
    ledCurrBrightness -= 2;
  }
                                                           // What to do when either sensor is activated

  if(USstartedFirst && (cm < usMaxRange)) {
    Serial.print("Chinging lights to:");
    sensorDetect = millis();
    //ledCurrBrightness = ledMaxBrightness * (constrain( distRange, 0,100 )) / 100;
    ledCurrBrightness = ledMaxBrightness;
    Serial.println(ledCurrBrightness);
    Serial.print("%range: ");
    Serial.println(distRange);
  }

  ledCurrBrightness = constrain(ledCurrBrightness, 0,255); // AnalogWrite can only do values between 0 and 255

  if (lightVal > pdDayLight) {
    ledCurrBrightness *= 0.5;
    Serial.println("Its light outside");
  }

  analogWrite(led1, ledCurrBrightness);                    // Sets all the current light values
  analogWrite(led2, ledCurrBrightness);
  analogWrite(led3, ledCurrBrightness);
  analogWrite(led4, ledCurrBrightness);

}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void OLEDcontrol() {                                         // Function for controlling the OLED screen
  display.clearDisplay();                                    // Starts off by clearing the screen and setting 
  display.setTextSize(2);                                    // the text size and
  display.setTextColor(SSD1306_WHITE);                       // the text color
 
  
  if (irrecv.decode(&results)) {                             // If the IR Receiver has a code...
    remoteVal = results.value;                               // Store it into the RemoteVal variable
    Serial.println(results.value);                           // Print the result to the serial port
    irrecv.resume();                                         // Allow further codes to be received from the sensor
  } else {
    remoteVal = "0";                                         // If not value was received, we set the remoteVal to 0 for no code
  }
  

  char tempCode[13];                                         // Conversion of the remoteVal to a long 
  remoteVal.toCharArray(tempCode,sizeof(tempCode));
  long longRemoteVal = atol(tempCode);


  if (t != 0) {                                              // pastO_state (pastOLED_state) controls the back-button action of the remote             
    pastO_state = h * 100;
  } else {
    pastO_state = OLED_state;
  }


  if ((shortRemoteVal == 3) && (UL_state != 4)){            // Control action when we press the center button
    if (UL_state % 2 == 0) {
        OLED_state += 10;
      } else {
        OLED_state += 20;
      }
  }


  

  switch (longRemoteVal) {                                  // Main control center when we press a button on the controller
    case 16736925:
      Serial.println(F("vol+")); 
      shortRemoteVal=1;
      if(UL_state != 4) {
        UL_state = (UL_state + 1) % 2;
        break;
      }
      
    case 16754775:
      Serial.println(F("vol-")); 
      shortRemoteVal=2;
      if (UL_state != 4){
        UL_state = (UL_state - 1) % 2;
        break;
      }
      
    case 16712445:
      Serial.println(F("play/pause")); 
      shortRemoteVal=3;
      if(h ==0) {
        break;
      }
      if (UL_state != 4){
        UL_state +=2;
      }
      break;
    case 16720605:
      Serial.println(F("skipBack")); 
      shortRemoteVal=4;
      if((h == 0) && (t != 0)) {
        break;
      }
      if(t!=0) {
        if (o > 0) {
          OLED_state -= 1;
        }
        
      } else {
        if(h > 0) {
          OLED_state -= 100;
        }
      }
      
      
      break;
    case 16761405:
      Serial.println(F("skipFront")); 
      shortRemoteVal=5;
      if((h == 0) && (t != 0)) {
        break;
      }
      if(t!=0) {
        if (o < 2) {
          OLED_state +=1;
        }
        
      } else {
        if (h < 2) {
          OLED_state += 100;
        }
      }
      
      break;
    case 16753245:
      Serial.println(F("Power"));
      OLED_state = 0;
      UL_state = 0;
      shortRemoteVal=6;
      break;
    case 16769565:
      Serial.println("Func Stop");
      OLED_state = pastO_state;
      UL_state = 0;
      shortRemoteVal = 7;
      break;
    default:
      //Serial.println(longRemoteVal);
      shortRemoteVal=0;
  }

  OLED_state = constrain(OLED_state,0,299);                 // Make sure OLED_state doesnt exceed 299 or go under 0
  h = OLED_state / 100;                                     // h = hundreds digit of OLED_state
  t = (OLED_state /10 ) % 10;                               // t = tens     digit of OLED_state
  o = OLED_state % 10;                                      // o = ones     digit of OLED_state
  //Serial.println(OLED_state);

  Serial.print(h);                                          // Prints the digits followed by a comma in the Serial Port
  Serial.print(", ");
  Serial.print(t);
  Serial.print(", ");
  Serial.println(o);

                                                        
  switch (h) {                                              // Main control center for actual text to display
    
    case 0:                                                 // Check picture Diagram to understand how this code works
      switch(t) {
        case 0:                             
          display.setCursor(16,8);  
          display.print(F("Rec Data"));
          display.setCursor(16, 40);
          display.print(F("Clear SD"));
          break;
        case 1: 
          if ((UL_state % 2) != 1) {                        // Forces Selecting outline to be on the second line
            UL_state += 1;
          }
          switch(o){
            case 0:
              display.setCursor(16,8);  
              if (isRecording) {
                display.print(F("Is Rec"));
              } else {
                display.print(F("Not Rec"));
              }
              
              display.setCursor(16, 40);

              if (isRecording) {
                display.print(F("Stop"));
              } else {
                display.print(F("Start"));
              }

              if (shortRemoteVal == 3) {                    // If center button is pressed
                Serial.println("PRESSED");
                shortRemoteVal = 0;
                OLED_state += 2;                            // add two, which gets us into the next case
              }
              
              break;
            case 2: 
              display.setCursor(16,8);  
              if (isRecording) {
                display.print(F("Stopping"));               // If we stop recording, we turn off is booted
                isBooted=false;
              } else {
                display.print(F("Starting"));               // Otherwise, we find a new filename and print the headers
           
                
              }
              display.setCursor(16, 40);
              display.print(F("Recording"));
              isRecording = !isRecording;                   // We turn isRecording to what it wasnt before (true -> false; false -> true)
              display.display();
              delay(2000);
              display.clearDisplay();
              OLED_state -=2;                               // We go back to the previous screen
              break;
          }
          
          break;
        case 2: 
          if ((UL_state % 2) != 1) {                        // Force the select outline to teh second line
            UL_state += 1;
          }
          switch(o) {
            case 0: 
              display.setCursor(16,8);  
              display.print(F("Delete?"));
              display.setCursor(16, 40);
              display.print(F("Yes"));

              if (shortRemoteVal == 3) {
                Serial.println("PRESSED");
                shortRemoteVal = 0;
                OLED_state += 2;                            // If we press button, we add 2, getting us to the next case
              }
              break;
            case 2:
              display.setCursor(16,8);  
              display.print(F("Deleting"));
              display.setCursor(16, 40);
              display.print(F("Files"));
              display.display();
              
                                           // Delete all files
              delay(4000);

              display.clearDisplay();
              display.setCursor(16,8);  
              display.print(F("Files"));
              display.setCursor(16, 40);
              display.print(F("Deleted!"));
              display.display();
              delay(2000);

              display.clearDisplay();
              OLED_state -= 2;                              // Return to previous screen
              break;
          }
          break;
          
      }
      
      break;
    case 1:                                                 // Second Main Screen
      bool values;
      if ((millis() % 10000) <= 5000) {
        values = true;
      }
      switch(t) {
        case 0: 
          display.setCursor(16,8);  
          display.print(F("Sensors1"));
          display.setCursor(16, 40);
          display.print(F("Sensors2"));
          break;
        case 1: 
          UL_state = 4;                                     // Turn off outline
          switch(o) {
            case 0: 
              display.setCursor(16,8);                      // 3 different pages of data
              display.print(F("Photores."));
              display.setCursor(16, 40);
              Wire.requestFrom(9,7);
              display.print(String(lightVal));
              break;
            case 1: 
              display.setCursor(16,8);  
              display.print(F("Humidity"));
              display.setCursor(16, 40);
              if (values) {
                display.print("29.0 %");
              } else {
                display.print("28.0 %");
              }
              
              break;
            case 2: 
              display.setCursor(16,8);  
              display.print(F("Temp."));
              display.setCursor(16, 40);
              if (values) {
                display.print("25.0 C");
              } else {
                display.print("27.0 C");
              }
              break;
          }
          break;
        case 2: 
          UL_state= 4;                                      // Turn off outline
          switch(o) {
            case 0: 
              display.setCursor(16,8);                      // 3 more different pages of data
              display.print(F("PIR Sens"));
              display.setCursor(16, 40);
              if (values) {
                display.print("Started");
              } else {
                display.print("Stopped");
              }
              break;
            case 1: 
              display.setCursor(16,8);  
              display.print(F("US Sens"));
              display.setCursor(16, 40);
              display.print(String(cm));
              break;
            case 2: 
              display.setCursor(16,8);  
              display.print(F("LTFC"));
              display.setCursor(16, 40);
              if (values) {
                display.print("10 mW/m2");
              } else {
                display.print("13 mW/m2");
              }
              break;
          }
          break;
      }
      break;
    case 2:
      switch(t){
        case 0:                                           // Credits for ASW and team who worked on the Project
          display.setCursor(16,8);  
          display.print(F("ASW"));
          display.setCursor(16, 40);
          display.print(F("Credits"));
          break;
        case 1:
          UL_state = 4;
          switch(o) {
            case 0:
              display.setCursor(16,8);  
              display.print(F("Adler"));
              display.setCursor(16, 40);
              display.print(F("Planetarium"));
              break;
            case 1:
              display.setCursor(16,8);  
              display.print(F("AstroScience"));
              display.setCursor(16, 40);
              display.print(F("WorkShop"));
              break;
            case 2:
              display.setCursor(16,8);  
              display.print(F("Teen"));
              display.setCursor(16, 40);
              display.print(F("Programs"));
              break;
          }
          break;
        case 2:
          UL_state = 4;
          switch(o) {
            case 0:
              display.setCursor(16,8);  
              display.print(F("Grace"));
              display.setCursor(16, 40);
              display.print(F("Structure"));
              break;
            case 1:
              display.setCursor(16,8);  
              display.print(F("Srijesh "));
              display.setCursor(16, 40);
              display.print(F("Electronics"));
              break;
            case 2:
              display.setCursor(16,8);  
              display.print(F("Juan"));
              display.setCursor(16, 40);
              display.print(F("Code"));
              break;
          }
      }
      
      break;
  }

  int rectyPos;                                           // Stores rectangle y position
  if (UL_state % 2 == 0) {                                // Changes depending on which line youre selecting
    rectyPos = 3;
  } else {
    rectyPos = 35;
  }

  if(UL_state <= 3) {                                     // Draws the rectangle, filled if we want to select 
    if (UL_state % 4 <=1){
      display.drawRoundRect(5, rectyPos, 123, 25, 4, WHITE);
     } else if(UL_state % 4 <= 3) {
      display.fillRoundRect(5, rectyPos, 123, 25, 4, WHITE);
      UL_state -=2;
    }
  }
  
  display.display();                                       // Displays finished product

}
